@@ -11,6 +11,7 @@ APP_MEDIA_RECEIVER = "CC1AD845"
 APP_PLEX = "06ee44ee-e7e3-4249-83b6-f5d0b6f07f34_1"
 APP_DASHCAST = "84912283"
 APP_SPOTIFY = "CC32E753"
+APP_HOME_ASSISTANT = "B12CE3CA"
 
 
 def get_possible_app_ids():
@@ -18,11 +19,11 @@ def get_possible_app_ids():
 
     try:
         req = requests.get(
-            "https://clients3.google.com/cast/chromecast/device/baseconfig")
+            "https://clients3.google.com/cast/chromecast/device/baseconfig"
+        )
         data = json.loads(req.text[4:])
 
-        return [app['app_id'] for app in data['applications']] + \
-            data["enabled_app_ids"]
+        return [app["app_id"] for app in data["applications"]] + data["enabled_app_ids"]
 
     except ValueError:
         # If json fails to parse
@@ -33,8 +34,10 @@ def get_app_config(app_id):
     """ Get specific configuration for 'app_id'. """
     try:
         req = requests.get(
-            ("https://clients3.google.com/"
-             "cast/chromecast/device/app?a={}").format(app_id))
+            ("https://clients3.google.com/" "cast/chromecast/device/app?a={}").format(
+                app_id
+            )
+        )
 
         return json.loads(req.text[4:]) if req.status_code == 200 else {}
 
